==> xSocket-1.0-sources.jar: org/xsocket/ClosedConnectionException.java <==
// $Id: ClosedConnectionException.java 931 2007-02-18 16:24:59Z grro $
/*
 *  Copyright (c) xsocket.org, 2006 - 2007. All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Please refer to the LGPL license at: http://www.gnu.org/copyleft/lesser.txt
 * The latest copy of this software may be found on http://www.xsocket.org/
 */
package org.xsocket;

import java.io.IOException;


/**
 * Checked exception thrown when an attempt is made 
 * to invoke or complete an I/O operation upon connection
 * that is closed, or at least closed to that operation. 
 * 
 * @author grro@xsocket.org 
 */
public class ClosedConnectionException extends IOException {

	private static final long serialVersionUID = 511131820240852835L;


	/**
	 * @see IOException
	 */
	public ClosedConnectionException(String msg) {
		super(msg);
	}

}

==> xSocket-1.1-sources.jar: org/xsocket/ClosedConnectionException.java <==
// $Id: ClosedConnectionException.java 1281 2007-05-29 19:48:07Z grro $
/*
 *  Copyright (c) xsocket.org, 2006 - 2007. All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Please refer to the LGPL license at: http://www.gnu.org/copyleft/lesser.txt
 * The latest copy of this software may be found on http://www.xsocket.org/
 */
package org.xsocket;

import java.io.IOException;


/**
 * Checked exception thrown when an attempt is made 
 * to invoke or complete an I/O operation upon connection
 * that is closed, or at least closed to that operation. 
 * 
 * @author grro@xsocket.org 
 */
public class ClosedConnectionException extends IOException {

	private static final long serialVersionUID = 511131820240852835L;


	/**
	 * constructor
	 * 
	 * @param msg the message
	 */
	public ClosedConnectionException(String msg) {
		super(msg);
	}


	/**
	 * constructor
	 * 
	 * @param msg    the message
	 * @param cause  the cause
	 */
	public ClosedConnectionException(String msg, Throwable cause) {
		super(msg);
		initCause(cause);
	}
}
